<?php

/**
 * @file
 * Contains Drupal\pinterest_hover\Form\ConfigForm.
 */

namespace Drupal\pinterest_hover\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Asset\AssetCollectionOptimizerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ConfigForm.
 *
 * @package Drupal\pinterest_hover\Form
 */
class ConfigForm extends ConfigFormBase {

  /**
   * The render cache bin.
   *
   * @var \Drupal\Core\Cache\CacheBackendInterface
   */
  protected $renderCache;

  /**
   * The JavaScript asset collection optimizer service.
   *
   * @var \Drupal\Core\Asset\AssetCollectionOptimizerInterface
   */
  protected $jsCollectionOptimizer;

  /**
   * Constructs a ConfigForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Cache\CacheBackendInterface $render_cache
   */
  public function __construct(ConfigFactoryInterface $config_factory, CacheBackendInterface $render_cache, AssetCollectionOptimizerInterface $js_collection_optimizer) {
    parent::__construct($config_factory);

    $this->renderCache = $render_cache;
    $this->jsCollectionOptimizer = $js_collection_optimizer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('cache.render'),
      $container->get('asset.js.collection_optimizer')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'pinterest_hover.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pinterest_hover_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('pinterest_hover.settings');
    /*
    $form['load_pinterest_js'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Add Pinterest script tag to all pages'),
      '#description' => $this->t('Whether this module should add a script tag to all pages loading Pinterest\'s JavaScript and enabling hover buttons. You may want to turn this off if you are including the Pinterest JavaScript in another way, such as in a different module or theme.'),
      '#default_value' => $config->get('load_pinterest_js'),
    ];
    */
    $form['exclude_hover_selectors'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Excluded items based on CSS selectors'),
      '#description' => $this->t('CSS selectors matching images that should not be pinnable or have Pin It hover buttons. One selector per line. Tip: to exclude all images in an area of your page, use descendant selectors like ".sidebar img"'),
      '#default_value' => $config->get('exclude_hover_selectors'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    // normalize line endings to \n
    $selectors = preg_replace('/[\r\n]+/', "\n", $form_state->getValue('exclude_hover_selectors'));

    $this->config('pinterest_hover.settings')
      ->set('load_pinterest_js', TRUE)
      ->set('exclude_hover_selectors', $selectors)
      ->save();


    /*
     * The below code from core's PerformanceForm looked promising for making
     * load_pinterest_js have an impact without a cache rebuild, but it didn't.
    $this->jsCollectionOptimizer->deleteAll();
    // This form allows page compression settings to be changed, which can
    // invalidate cached pages in the render cache, so it needs to be cleared on
    // form submit.
    $this->renderCache->deleteAll();
    */
  }

}
